"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AdminUsersPermissions = void 0;
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var _taggedTemplateLiteral2 = _interopRequireDefault(require("@babel/runtime/helpers/taggedTemplateLiteral"));
var _react = _interopRequireWildcard(require("react"));
var _Grid = require("@webiny/ui/Grid");
var _Select = require("@webiny/ui/Select");
var _i18n = require("@webiny/app/i18n");
var _Permissions = require("@webiny/app-admin/components/Permissions");
var _form = require("@webiny/form");
var _Elevation = require("@webiny/ui/Elevation");
var _Typography = require("@webiny/ui/Typography");
var _appSecurity = require("@webiny/app-security");
var _excluded = ["value"];
var _templateObject, _templateObject2, _templateObject3, _templateObject4, _templateObject5, _templateObject6, _templateObject7, _templateObject8, _templateObject9;
var t = _i18n.i18n.ns("app-security-admin-users/plugins/permissionRenderer");
var ADMIN_USERS = "adminUsers";
var ADMIN_USERS_FULL_ACCESS = "".concat(ADMIN_USERS, ".*");
var ADMIN_USERS_USER_ACCESS = "".concat(ADMIN_USERS, ".user");
var FULL_ACCESS = "full";
var NO_ACCESS = "no";
var CUSTOM_ACCESS = "custom";
var AdminUsersPermissions = exports.AdminUsersPermissions = function AdminUsersPermissions(_ref) {
  var value = _ref.value,
    onChange = _ref.onChange;
  var _useSecurity = (0, _appSecurity.useSecurity)(),
    getPermission = _useSecurity.getPermission;

  // We disable form elements for custom permissions if AACL cannot be used.
  var cannotUseAAcl = (0, _react.useMemo)(function () {
    return !getPermission("aacl", true);
  }, []);
  var onFormChange = (0, _react.useCallback)(function (data) {
    var newValue = [];
    if (Array.isArray(value)) {
      // Let's just filter out the `security*` permission objects, it's easier to build new ones from scratch.
      newValue = value.filter(function (item) {
        return !item.name.startsWith(ADMIN_USERS);
      });
    }
    var permissions = [];
    if (data.accessLevel === FULL_ACCESS) {
      permissions.push({
        name: ADMIN_USERS_FULL_ACCESS
      });
    } else if (data.accessLevel === CUSTOM_ACCESS) {
      if (data.userAccessScope === FULL_ACCESS) {
        permissions.push({
          name: ADMIN_USERS_USER_ACCESS
        });
      }
    }
    if (permissions && permissions.length) {
      var _newValue;
      (_newValue = newValue).push.apply(_newValue, permissions);
    }
    onChange(newValue);
  }, [value]);
  var formData = (0, _react.useMemo)(function () {
    if (!Array.isArray(value)) {
      return {
        accessLevel: NO_ACCESS
      };
    }
    var hasFullAccess = value.find(function (item) {
      return item.name === ADMIN_USERS_FULL_ACCESS || item.name === "*";
    });
    if (hasFullAccess) {
      return {
        accessLevel: FULL_ACCESS
      };
    }
    var permissions = value.filter(function (item) {
      return item.name.startsWith(ADMIN_USERS);
    });
    if (permissions.length === 0) {
      return {
        accessLevel: NO_ACCESS
      };
    }
    var data = {
      accessLevel: CUSTOM_ACCESS,
      userAccessScope: NO_ACCESS
    };
    var hasUserAccess = permissions.find(function (item) {
      return item.name === ADMIN_USERS_USER_ACCESS;
    });
    if (hasUserAccess) {
      data.userAccessScope = FULL_ACCESS;
    }
    return data;
  }, []);
  return /*#__PURE__*/_react.default.createElement(_form.Form, {
    data: formData,
    onChange: onFormChange
  }, function (_ref2) {
    var data = _ref2.data,
      Bind = _ref2.Bind;
    var disableUserAccessScope = data.groupAccessScope === NO_ACCESS;
    return /*#__PURE__*/_react.default.createElement(_react.Fragment, null, /*#__PURE__*/_react.default.createElement(_Grid.Grid, {
      className: _Permissions.gridNoPaddingClass
    }, /*#__PURE__*/_react.default.createElement(_Grid.Cell, {
      span: 12
    }, data.accessLevel === "custom" && cannotUseAAcl && /*#__PURE__*/_react.default.createElement(_Permissions.CannotUseAaclAlert, null))), /*#__PURE__*/_react.default.createElement(_Grid.Grid, {
      className: _Permissions.gridNoPaddingClass
    }, /*#__PURE__*/_react.default.createElement(_Grid.Cell, {
      span: 6
    }, /*#__PURE__*/_react.default.createElement(_Permissions.PermissionInfo, {
      title: t(_templateObject || (_templateObject = (0, _taggedTemplateLiteral2.default)(["Access Level"])))
    })), /*#__PURE__*/_react.default.createElement(_Grid.Cell, {
      span: 6
    }, /*#__PURE__*/_react.default.createElement(Bind, {
      name: "accessLevel"
    }, /*#__PURE__*/_react.default.createElement(_Select.Select, {
      label: t(_templateObject2 || (_templateObject2 = (0, _taggedTemplateLiteral2.default)(["Access Level"])))
    }, /*#__PURE__*/_react.default.createElement("option", {
      value: NO_ACCESS
    }, t(_templateObject3 || (_templateObject3 = (0, _taggedTemplateLiteral2.default)(["No access"])))), /*#__PURE__*/_react.default.createElement("option", {
      value: FULL_ACCESS
    }, t(_templateObject4 || (_templateObject4 = (0, _taggedTemplateLiteral2.default)(["Full access"])))), /*#__PURE__*/_react.default.createElement("option", {
      value: CUSTOM_ACCESS
    }, t(_templateObject5 || (_templateObject5 = (0, _taggedTemplateLiteral2.default)(["Custom access"])))))))), data.accessLevel === CUSTOM_ACCESS && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_Elevation.Elevation, {
      z: 1,
      style: {
        marginTop: 10
      }
    }, /*#__PURE__*/_react.default.createElement(_Grid.Grid, null, /*#__PURE__*/_react.default.createElement(_Grid.Cell, {
      span: 12
    }, /*#__PURE__*/_react.default.createElement(_Typography.Typography, {
      use: "overline"
    }, t(_templateObject6 || (_templateObject6 = (0, _taggedTemplateLiteral2.default)(["Users"]))))), /*#__PURE__*/_react.default.createElement(_Grid.Cell, {
      span: 12
    }, /*#__PURE__*/_react.default.createElement(Bind, {
      name: "userAccessScope"
    }, function (_ref3) {
      var value = _ref3.value,
        props = (0, _objectWithoutProperties2.default)(_ref3, _excluded);
      return /*#__PURE__*/_react.default.createElement(_Select.Select, Object.assign({}, props, {
        label: t(_templateObject7 || (_templateObject7 = (0, _taggedTemplateLiteral2.default)(["Access Scope"]))),
        disabled: cannotUseAAcl || disableUserAccessScope,
        value: disableUserAccessScope ? NO_ACCESS : value
      }), /*#__PURE__*/_react.default.createElement("option", {
        value: NO_ACCESS
      }, t(_templateObject8 || (_templateObject8 = (0, _taggedTemplateLiteral2.default)(["No access"])))), /*#__PURE__*/_react.default.createElement("option", {
        value: FULL_ACCESS
      }, t(_templateObject9 || (_templateObject9 = (0, _taggedTemplateLiteral2.default)(["Full access"])))));
    }))))));
  });
};

//# sourceMappingURL=AdminUsersPermissions.js.map