"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.UserInfo = void 0;
var _react = _interopRequireDefault(require("react"));
var _emotion = require("emotion");
var _reactRouter = require("@webiny/react-router");
var _useSecurity = require("@webiny/app-security/hooks/useSecurity");
var _components = require("@webiny/app/components");
var _List = require("@webiny/ui/List");
var _Typography = require("@webiny/ui/Typography");
var _Avatar = require("@webiny/ui/Avatar");
var _useIsDefaultTenant = require("./useIsDefaultTenant");
var avatarImage = (0, _emotion.css)({
  height: "40px !important",
  width: "40px !important",
  borderRadius: "50%",
  display: "inline-block",
  ">div": {
    backgroundColor: "var(--mdc-theme-surface)"
  }
});
var linkStyles = (0, _emotion.css)({
  backgroundColor: "var(--mdc-theme-background)",
  marginTop: -25,
  marginBottom: 0,
  paddingTop: 0,
  paddingBottom: 0,
  textDecoration: "none",
  display: "block",
  "&:hover": {
    textDecoration: "none"
  },
  ">.mdc-deprecated-list-item": {
    display: "flex",
    height: "65px !important",
    marginTop: 15,
    ".avatar": {
      marginTop: 10
    }
  },
  "h3, h3>.mdc-typography--headline6": {
    lineHeight: "1em !important"
  },
  ".mdc-menu &.mdc-deprecated-list-item": {
    ">.mdc-deprecated-list-item__text": {
      fontWeight: "bold"
    }
  },
  ".mdc-deprecated-list-item": {
    height: "auto",
    ".mdc-typography--headline6": {
      overflow: "hidden",
      whiteSpace: "nowrap",
      textOverflow: "ellipsis",
      maxWidth: 180,
      display: "block"
    },
    ".mdc-typography--body2": {
      overflow: "hidden",
      whiteSpace: "nowrap",
      textOverflow: "ellipsis",
      maxWidth: 180
    }
  }
});
var UserInfo = exports.UserInfo = function UserInfo(_ref) {
  var accountRoute = _ref.accountRoute;
  var security = (0, _useSecurity.useSecurity)();
  if (!security || !security.identity) {
    return null;
  }
  var _security$identity = security.identity,
    profile = _security$identity.profile,
    displayName = _security$identity.displayName;

  // Start with the assumption that the user doesn't have a profile in the system (external IDP).
  var listItem = /*#__PURE__*/_react.default.createElement(UserInfoListItem, {
    displayName: displayName
  });
  if (profile) {
    var email = profile.email,
      firstName = profile.firstName,
      lastName = profile.lastName,
      avatar = profile.avatar,
      gravatar = profile.gravatar;
    var fullName = "".concat(firstName, " ").concat(lastName);
    listItem = /*#__PURE__*/_react.default.createElement(UserInfoListItem, {
      displayName: fullName,
      avatarSrc: avatar ? avatar.src : gravatar,
      email: email
    });
  }
  return /*#__PURE__*/_react.default.createElement(UserInfoListItemContainer, {
    accountRoute: accountRoute,
    className: linkStyles
  }, listItem);
};
var UserInfoListItemContainer = function UserInfoListItemContainer(_ref2) {
  var accountRoute = _ref2.accountRoute,
    className = _ref2.className,
    children = _ref2.children;
  var isDefaultTenant = (0, _useIsDefaultTenant.useIsDefaultTenant)();

  // If there's no "accountRoute", or the user is not on his default tenant, don't render the link to "Account Details".
  if (!accountRoute || !isDefaultTenant) {
    return /*#__PURE__*/_react.default.createElement("div", {
      className: className
    }, children);
  }
  return /*#__PURE__*/_react.default.createElement(_reactRouter.Link, {
    to: accountRoute,
    className: className
  }, children);
};
var UserInfoListItem = function UserInfoListItem(_ref3) {
  var avatarSrc = _ref3.avatarSrc,
    displayName = _ref3.displayName,
    email = _ref3.email;
  return /*#__PURE__*/_react.default.createElement(_List.ListItem, {
    ripple: false,
    className: linkStyles
  }, /*#__PURE__*/_react.default.createElement(_List.ListItemGraphic, {
    className: avatarImage
  }, /*#__PURE__*/_react.default.createElement(_Avatar.Avatar, {
    className: "avatar",
    src: avatarSrc,
    alt: displayName,
    fallbackText: displayName,
    renderImage: function renderImage(props) {
      return /*#__PURE__*/_react.default.createElement(_components.Image, Object.assign({}, props, {
        transform: {
          width: 100
        }
      }));
    }
  })), /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_Typography.Typography, {
    use: "headline6"
  }, displayName), email ? /*#__PURE__*/_react.default.createElement(_Typography.Typography, {
    use: "body2"
  }, email) : null));
};
var _default = exports.default = function _default() {
  console.log("[DEPRECATED] Import \"@webiny/app-admin-users-cognito/plugins/userMenu/userInfo\" is no longer used!");
  return {
    type: "dummy"
  };
};

//# sourceMappingURL=userInfo.js.map