"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _taggedTemplateLiteral2 = _interopRequireDefault(require("@babel/runtime/helpers/taggedTemplateLiteral"));
var _react = _interopRequireWildcard(require("react"));
var _reactHooks = require("@apollo/react-hooks");
var _orderBy = _interopRequireDefault(require("lodash/orderBy"));
var _i18n = require("@webiny/app/i18n");
var _components = require("@webiny/app/components");
var _List = require("@webiny/ui/List");
var _Button = require("@webiny/ui/Button");
var _Avatar = require("@webiny/ui/Avatar");
var _Grid = require("@webiny/ui/Grid");
var _Select = require("@webiny/ui/Select");
var _reactRouter = require("@webiny/react-router");
var _useSnackbar2 = require("@webiny/app-admin/hooks/useSnackbar");
var _useConfirmationDialog = require("@webiny/app-admin/hooks/useConfirmationDialog");
var _SearchUI = _interopRequireDefault(require("@webiny/app-admin/components/SearchUI"));
var _add18px = require("@webiny/app-admin/assets/icons/add-18px.svg");
var _filter24px = require("@webiny/app-admin/assets/icons/filter-24px.svg");
var _graphql = require("./graphql");
var _utils = require("../utils");
var _DeleteAction = require("./components/DeleteAction");
var _templateObject, _templateObject2, _templateObject3, _templateObject4, _templateObject5, _templateObject6, _templateObject7, _templateObject8, _templateObject9, _templateObject10;
var t = _i18n.i18n.ns("app-identity/admin/users/data-list");
var SORTERS = [{
  label: t(_templateObject || (_templateObject = (0, _taggedTemplateLiteral2.default)(["Newest to oldest"]))),
  sorter: "createdOn_DESC"
}, {
  label: t(_templateObject2 || (_templateObject2 = (0, _taggedTemplateLiteral2.default)(["Oldest to newest"]))),
  sorter: "createdOn_ASC"
}, {
  label: t(_templateObject3 || (_templateObject3 = (0, _taggedTemplateLiteral2.default)(["Email A-Z"]))),
  sorter: "email_ASC"
}, {
  label: t(_templateObject4 || (_templateObject4 = (0, _taggedTemplateLiteral2.default)(["Email Z-A"]))),
  sorter: "email_DESC"
}];
var UsersDataList = function UsersDataList() {
  var _useState = (0, _react.useState)(""),
    _useState2 = (0, _slicedToArray2.default)(_useState, 2),
    filter = _useState2[0],
    setFilter = _useState2[1];
  var _useState3 = (0, _react.useState)(SORTERS[0].sorter),
    _useState4 = (0, _slicedToArray2.default)(_useState3, 2),
    sort = _useState4[0],
    setSort = _useState4[1];
  var _useRouter = (0, _reactRouter.useRouter)(),
    history = _useRouter.history;
  var _useSnackbar = (0, _useSnackbar2.useSnackbar)(),
    showSnackbar = _useSnackbar.showSnackbar;
  var _useConfirmationDialo = (0, _useConfirmationDialog.useConfirmationDialog)({
      dataTestId: "default-data-list.delete-dialog"
    }),
    showConfirmation = _useConfirmationDialo.showConfirmation;
  var filterUsers = (0, _react.useCallback)(function (_ref) {
    var email = _ref.email,
      firstName = _ref.firstName,
      lastName = _ref.lastName;
    return email.toLowerCase().includes(filter) || firstName.toLowerCase().includes(filter) || lastName.toLowerCase().includes(filter);
  }, [filter]);
  var sortUsers = (0, _react.useCallback)(function (users) {
    if (!sort) {
      return users;
    }
    var _deserializeSorters = (0, _utils.deserializeSorters)(sort),
      _deserializeSorters2 = (0, _slicedToArray2.default)(_deserializeSorters, 2),
      key = _deserializeSorters2[0],
      sortBy = _deserializeSorters2[1];
    return (0, _orderBy.default)(users, [key], [sortBy]);
  }, [sort]);
  var _useQuery = (0, _reactHooks.useQuery)(_graphql.LIST_USERS),
    listUsers = _useQuery.data,
    usersLoading = _useQuery.loading;
  var _useMutation = (0, _reactHooks.useMutation)(_graphql.DELETE_USER, {
      refetchQueries: [{
        query: _graphql.LIST_USERS
      }]
    }),
    _useMutation2 = (0, _slicedToArray2.default)(_useMutation, 2),
    deleteIt = _useMutation2[0],
    deleteLoading = _useMutation2[1].loading;
  var data = usersLoading && !listUsers ? [] : listUsers.adminUsers.users.data || [];
  var filteredData = filter === "" ? data : data.filter(filterUsers);
  var userList = sortUsers(filteredData);
  var id = new URLSearchParams(location.search).get("id");
  var deleteItem = (0, _react.useCallback)(function (item) {
    showConfirmation(async function () {
      var response = await deleteIt({
        variables: item
      });
      var error = response?.data?.adminUsers?.deleteUser?.error;
      if (error) {
        return showSnackbar(error.message);
      }
      showSnackbar(t(_templateObject5 || (_templateObject5 = (0, _taggedTemplateLiteral2.default)(["User \"{email}\" deleted."])))({
        email: item.email
      }));
      if (id === item.id) {
        history.push("/admin-users");
      }
    });
  }, [id]);
  var usersDataListModalOverlay = (0, _react.useMemo)(function () {
    return /*#__PURE__*/_react.default.createElement(_List.DataListModalOverlay, null, /*#__PURE__*/_react.default.createElement(_Grid.Grid, null, /*#__PURE__*/_react.default.createElement(_Grid.Cell, {
      span: 12
    }, /*#__PURE__*/_react.default.createElement(_Select.Select, {
      value: sort,
      onChange: setSort,
      label: t(_templateObject6 || (_templateObject6 = (0, _taggedTemplateLiteral2.default)(["Sort by"])))
    }, SORTERS.map(function (_ref2) {
      var label = _ref2.label,
        sorter = _ref2.sorter;
      return /*#__PURE__*/_react.default.createElement("option", {
        key: label,
        value: sorter
      }, label);
    })))));
  }, [sort]);
  var loading = usersLoading || deleteLoading;
  return /*#__PURE__*/_react.default.createElement(_List.DataList, {
    title: t(_templateObject7 || (_templateObject7 = (0, _taggedTemplateLiteral2.default)(["Admin Users"]))),
    actions: /*#__PURE__*/_react.default.createElement(_Button.ButtonSecondary, {
      "data-testid": "new-record-button",
      onClick: function onClick() {
        return history.push("/admin-users?new=true");
      }
    }, /*#__PURE__*/_react.default.createElement(_Button.ButtonIcon, {
      icon: /*#__PURE__*/_react.default.createElement(_add18px.ReactComponent, null)
    }), " ", t(_templateObject8 || (_templateObject8 = (0, _taggedTemplateLiteral2.default)(["New User"])))),
    data: userList,
    loading: loading,
    search: /*#__PURE__*/_react.default.createElement(_SearchUI.default, {
      value: filter,
      onChange: setFilter,
      inputPlaceholder: t(_templateObject9 || (_templateObject9 = (0, _taggedTemplateLiteral2.default)(["Search users"])))
    }),
    modalOverlay: usersDataListModalOverlay,
    modalOverlayAction: /*#__PURE__*/_react.default.createElement(_List.DataListModalOverlayAction, {
      icon: /*#__PURE__*/_react.default.createElement(_filter24px.ReactComponent, null),
      "data-testid": "default-data-list.filter"
    })
  }, function (_ref3) {
    var data = _ref3.data;
    return /*#__PURE__*/_react.default.createElement(_List.ScrollList, {
      twoLine: true,
      avatarList: true,
      "data-testid": "default-data-list"
    }, data.map(function (item) {
      return /*#__PURE__*/_react.default.createElement(_List.ListItem, {
        key: item.id,
        selected: item.id === id,
        style: {
          height: "auto"
        }
      }, /*#__PURE__*/_react.default.createElement(_List.ListItemGraphic, null, /*#__PURE__*/_react.default.createElement(_Avatar.Avatar, {
        renderImage: function renderImage(props) {
          return /*#__PURE__*/_react.default.createElement(_components.Image, Object.assign({}, props, {
            transform: {
              width: 100
            }
          }));
        },
        src: item.avatar ? item.avatar.src : item.gravatar,
        fallbackText: item.firstName,
        alt: t(_templateObject10 || (_templateObject10 = (0, _taggedTemplateLiteral2.default)(["User's avatar."])))
      })), /*#__PURE__*/_react.default.createElement(_List.ListItemText, {
        onClick: function onClick() {
          return history.push("/admin-users?id=".concat(item.id));
        }
      }, item.firstName, " ", item.lastName, /*#__PURE__*/_react.default.createElement(_List.ListItemTextSecondary, null, item.email)), /*#__PURE__*/_react.default.createElement(_List.ListItemMeta, null, /*#__PURE__*/_react.default.createElement(_List.ListActions, null, /*#__PURE__*/_react.default.createElement(_DeleteAction.DeleteAction, {
        item: item,
        onClick: function onClick() {
          return deleteItem(item);
        }
      }))));
    }));
  });
};
var _default = exports.default = UsersDataList;

//# sourceMappingURL=UsersDataList.js.map