"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useUserForm = useUserForm;
var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _react = require("react");
var _reactHooks = require("@apollo/react-hooks");
var _isEmpty = _interopRequireDefault(require("lodash/isEmpty"));
var _reactRouter = require("@webiny/react-router");
var _useSnackbar2 = require("@webiny/app-admin/hooks/useSnackbar");
var _graphql = require("../graphql");
var _appAdmin = require("@webiny/app-admin");
var _omit = _interopRequireDefault(require("lodash/omit"));
var _excluded = ["id"];
function useUserForm() {
  var _useRouter = (0, _reactRouter.useRouter)(),
    location = _useRouter.location,
    history = _useRouter.history;
  var _useSnackbar = (0, _useSnackbar2.useSnackbar)(),
    showSnackbar = _useSnackbar.showSnackbar;
  var wcp = (0, _appAdmin.useWcp)();
  var teams = wcp.canUseTeams();
  var query = new URLSearchParams(location.search);
  var id = query.get("id");
  var newUser = !id;
  var _useQuery = (0, _reactHooks.useQuery)((0, _graphql.READ_USER)({
      teams: teams
    }), {
      variables: {
        id: id
      },
      skip: !id,
      onCompleted: function onCompleted(data) {
        if (!data) {
          return;
        }
        var error = data.adminUsers.user.error;
        if (error) {
          history.push("/admin-users");
          showSnackbar(error.message);
        }
      }
    }),
    data = _useQuery.data,
    userLoading = _useQuery.loading;
  var _useMutation = (0, _reactHooks.useMutation)(_graphql.CREATE_USER, {
      refetchQueries: [{
        query: _graphql.LIST_USERS
      }]
    }),
    _useMutation2 = (0, _slicedToArray2.default)(_useMutation, 2),
    create = _useMutation2[0],
    createLoading = _useMutation2[1].loading;
  var _useMutation3 = (0, _reactHooks.useMutation)((0, _graphql.UPDATE_USER)({
      teams: teams
    }), {
      refetchQueries: [{
        query: _graphql.LIST_USERS
      }]
    }),
    _useMutation4 = (0, _slicedToArray2.default)(_useMutation3, 2),
    update = _useMutation4[0],
    updateLoading = _useMutation4[1].loading;
  var loading = userLoading || createLoading || updateLoading;
  var onSubmit = (0, _react.useCallback)(async function (data) {
    var id = data.id,
      rest = (0, _objectWithoutProperties2.default)(data, _excluded);
    var _ref = !newUser ? [update, {
        variables: {
          id: id,
          data: (0, _omit.default)(rest, ["external"])
        }
      }] : [create, {
        variables: {
          data: data
        }
      }],
      _ref2 = (0, _slicedToArray2.default)(_ref, 2),
      operation = _ref2[0],
      args = _ref2[1];
    var result = await operation(args);
    var _result$data$adminUse = result.data.adminUsers.user,
      user = _result$data$adminUse.data,
      error = _result$data$adminUse.error;
    if (error) {
      return showSnackbar(error.message);
    }
    newUser && history.push("/admin-users?id=".concat(user.id));
    showSnackbar("User saved successfully.");
  }, [id]);
  var user = userLoading ? {} : data ? data.adminUsers.user.data : {};
  var showEmptyView = !newUser && !userLoading && (0, _isEmpty.default)(user);
  return {
    id: id,
    loading: loading,
    user: (0, _objectSpread2.default)((0, _objectSpread2.default)({}, user), {}, {
      group: user.group ? user.group.id : undefined,
      team: user.team ? user.team.id : undefined
    }),
    onSubmit: onSubmit,
    isNewUser: newUser,
    fullName: "".concat(user.firstName || "", " ").concat(user.lastName || "").trim(),
    showEmptyView: showEmptyView,
    createUser: function createUser() {
      history.push("/admin-users?new=true");
    },
    cancelEditing: function cancelEditing() {
      history.push("/admin-users");
    }
  };
}

//# sourceMappingURL=useUserForm.js.map